Actions, Resources, and Condition Keys for Amazon Managed Streaming for Kafka - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Managed Streaming for Kafka.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon Managed Streaming for Kafka

Amazon Managed Streaming for Kafka (service prefix: `kafka`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

Topics

- Actions Defined by Amazon Managed Streaming for Kafka
- Resources Defined by Amazon Managed Streaming for Kafka
- Condition Keys for Amazon Managed Streaming for Kafka

## Actions Defined by Amazon Managed Streaming for Kafka

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateCluster | Grants permission to create a cluster. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcs iam:AttachRolePolicy iam:CreateServiceLinkedRole iam:PutRolePolicy kms:CreateGrant kms:DescribeKey
CreateConfiguration | Grants permission to create a configuration. | Write |  |  |
DeleteCluster | Grants permission to delete a cluster. | Write |  |  |
DescribeCluster | Grants permission to describe a cluster. | Read |  |  |
DescribeClusterOperation | Returns a description of the cluster operation specified by the ARN. | Read |  |  |
DescribeConfiguration | Grants permission to describe a configuration. | Read |  |  |
DescribeConfigurationRevision | Grants permission to describe a configuration revision. | Read |  |  |
GetBootstrapBrokers | Grants permission to get connection details for the broker nodes in a cluster. | Read |  |  |
ListClusterOperations | Returns a list of all the operations that have been performed on the specified MSK cluster. | Read |  |  |
ListClusters | Grants permission to return a list of all clusters in the current account. | List |  |  |
ListConfigurations | Grants permission to return a list of all configurations in the current account. | List |  |  |
ListNodes | Grants permission to return a list of nodes in a cluster. | List |  |  |
ListTagsForResource | Grants permission to list tags of a MSK resource. | Read | cluster |  |
TagResource | Grants permission to tag a MSK resource. | Tagging | cluster |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove tags from a MSK resource. | Tagging | cluster |  |
| aws:TagKeys |
UpdateBrokerStorage | Updates the storage size of the broker nodes of the cluster | Write |  |  |
UpdateClusterConfiguration | Update Kafka configuration running on a cluster. | Write |  |  |

## Resources Defined by Amazon Managed Streaming for Kafka

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
cluster | `arn:${Partition}:kafka:${Region}:${Account}:cluster/${ClusterName}/${UUID}` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon Managed Streaming for Kafka

Amazon Managed Streaming for Kafka defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filter requests based on the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filter actions based on tag-value associated with a MSK resource. | String
aws:TagKeys | Filter requests based on the presence of mandatory tag keys in the request | String

On this page:

- Actions Defined by Amazon Managed Streaming for Kafka
- Resources Defined by Amazon Managed Streaming for Kafka
- Condition Keys for Amazon Managed Streaming for Kafka

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more